```
Usage: vcd vdc create [OPTIONS] <name>

Options:
  -p, --provider-vdc [provider-vdc]
                                  Provider VDC  [required]
  -n, --network-pool [network-pool]
                                  Network pool
  -a, --allocation-model <allocation-model>
                                  Allocation model.
  -s, --storage-profile [storage-profile]
                                  Provider VDC Storage Profile.
  --storage-profile-limit [storage-profile-limit]
                                  Provider VDC Storage Profile limit (MB), 0
                                  means unlimited.
  -D, --description [description]
                                  description.
  --cpu-allocated <cpu-allocated>
                                  Capacity that is commited to be available.
  --cpu-limit <cpu-limit>         Capacity limit relative to the value
                                  specified for Allocation.
  -h, --help                      Show this message and exit.

```
